com.biffweb.authenticate


hcaptcha-configclj

Captcha config keys for hCaptcha.

Include this map in the options passed to routes / module.

Captcha config keys for hCaptcha.

Include this map in the options passed to `routes` / `module`.
sourceraw docstring

moduleclj

(module options)

A biff.core module that includes routes under :biff.ring/routes.

A biff.core module that includes `routes` under :biff.ring/routes.
sourceraw docstring

recaptcha-configclj

Captcha config keys for Google reCAPTCHA.

Include this map in the options passed to routes / module.

Captcha config keys for Google reCAPTCHA.

Include this map in the options passed to `routes` / `module`.
sourceraw docstring

routesclj

(routes options)

Returns a collection of Reitit routes with options merged into requests.

Configuration:

  • :biff.auth/captcha-configured?
  • :biff.auth/include-signin-page
  • :biff.auth/skip-captcha
  • :biff.auth/skip-csrf-protection
  • Additional configuration keys recognized by the individual routes

See docs/routes.md and docs/config.md. Configuration may be passed in options or included in Ring request maps.

Returns a collection of Reitit routes with `options` merged into requests.

Configuration:

- :biff.auth/captcha-configured?
- :biff.auth/include-signin-page
- :biff.auth/skip-captcha
- :biff.auth/skip-csrf-protection
- Additional configuration keys recognized by the individual routes

See docs/routes.md and docs/config.md. Configuration may be passed in
`options` or included in Ring request maps.
sourceraw docstring

signout-pathclj

The URI path for the signout handler provided by routes / module.

To sign out, send a POST request to this path.

The URI path for the signout handler provided by `routes` / `module`.

To sign out, send a POST request to this path.
sourceraw docstring

turnstile-configclj

Captcha config keys for Cloudflare Turnstile.

Include this map in the options passed to routes / module.

Captcha config keys for Cloudflare Turnstile.

Include this map in the options passed to `routes` / `module`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries