Captcha config keys for hCaptcha.
Include this map in the options passed to routes / module.
Captcha config keys for hCaptcha. Include this map in the options passed to `routes` / `module`.
(module options)A biff.core module that includes routes under :biff.ring/routes.
A biff.core module that includes `routes` under :biff.ring/routes.
Captcha config keys for Google reCAPTCHA.
Include this map in the options passed to routes / module.
Captcha config keys for Google reCAPTCHA. Include this map in the options passed to `routes` / `module`.
(routes options)Returns a collection of Reitit routes with options merged into requests.
Configuration:
See docs/routes.md and docs/config.md. Configuration may be passed in
options or included in Ring request maps.
Returns a collection of Reitit routes with `options` merged into requests. Configuration: - :biff.auth/captcha-configured? - :biff.auth/include-signin-page - :biff.auth/skip-captcha - :biff.auth/skip-csrf-protection - Additional configuration keys recognized by the individual routes See docs/routes.md and docs/config.md. Configuration may be passed in `options` or included in Ring request maps.
The URI path for the signout handler provided by routes / module.
To sign out, send a POST request to this path.
The URI path for the signout handler provided by `routes` / `module`. To sign out, send a POST request to this path.
Captcha config keys for Cloudflare Turnstile.
Include this map in the options passed to routes / module.
Captcha config keys for Cloudflare Turnstile. Include this map in the options passed to `routes` / `module`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |